==> php-nesbot-carbon_2.32.2.orig.tar.xz: php-nesbot-carbon-2.32.2/tests/Localization/HeIlTest.php <==
<?php
declare(strict_types=1);

/**
 * This file is part of the Carbon package.
 *
 * (c) Brian Nesbitt <brian@nesbot.com>
 *
 * For the full copyright and license information, please view the LICENSE
 * file that was distributed with this source code.
 */
namespace Tests\Localization;

class HeIlTest extends LocalizationTestCase
{
    const LOCALE = 'he_IL'; // Hebrew

    const CASES = [
        // Carbon::parse('2018-01-04 00:00:00')->addDays(1)->calendar(Carbon::parse('2018-01-04 00:00:00'))
        'מחר ב־00:00',
        // Carbon::parse('2018-01-04 00:00:00')->addDays(2)->calendar(Carbon::parse('2018-01-04 00:00:00'))
        'שבת בשעה 00:00',
        // Carbon::parse('2018-01-04 00:00:00')->addDays(3)->calendar(Carbon::parse('2018-01-04 00:00:00'))
        'ראשון בשעה 00:00',
        // Carbon::parse('2018-01-04 00:00:00')->addDays(4)->calendar(Carbon::parse('2018-01-04 00:00:00'))
        'שני בשעה 00:00',
        // Carbon::parse('2018-01-04 00:00:00')->addDays(5)->calendar(Carbon::parse('2018-01-04 00:00:00'))
        'שלישי בשעה 00:00',
        // Carbon::parse('2018-01-04 00:00:00')->addDays(6)->calendar(Carbon::parse('2018-01-04 00:00:00'))
        'רביעי בשעה 00:00',
        // Carbon::parse('2018-01-05 00:00:00')->addDays(6)->calendar(Carbon::parse('2018-01-05 00:00:00'))
        'חמישי בשעה 00:00',
        // Carbon::parse('2018-01-06 00:00:00')->addDays(6)->calendar(Carbon::parse('2018-01-06 00:00:00'))
        'שישי בשעה 00:00',
        // Carbon::parse('2018-01-07 00:00:00')->addDays(2)->calendar(Carbon::parse('2018-01-07 00:00:00'))
        'שלישי בשעה 00:00',
        // Carbon::parse('2018-01-07 00:00:00')->addDays(3)->calendar(Carbon::parse('2018-01-07 00:00:00'))
        'רביעי בשעה 00:00',
        // Carbon::parse('2018-01-07 00:00:00')->addDays(4)->calendar(Carbon::parse('2018-01-07 00:00:00'))
        'חמישי בשעה 00:00',
        // Carbon::parse('2018-01-07 00:00:00')->addDays(5)->calendar(Carbon::parse('2018-01-07 00:00:00'))
        'שישי בשעה 00:00',
        // Carbon::parse('2018-01-07 00:00:00')->addDays(6)->calendar(Carbon::parse('2018-01-07 00:00:00'))
        'שבת בשעה 00:00',
        // Carbon::now()->subDays(2)->calendar()
        'ביום ראשון האחרון בשעה 20:49',
        // Carbon::parse('2018-01-04 00:00:00')->subHours(2)->calendar(Carbon::parse('2018-01-04 00:00:00'))
        'אתמול ב־22:00',
        // Carbon::parse('2018-01-04 12:00:00')->subHours(2)->calendar(Carbon::parse('2018-01-04 12:00:00'))
        'היום ב־10:00',
        // Carbon::parse('2018-01-04 00:00:00')->addHours(2)->calendar(Carbon::parse('2018-01-04 00:00:00'))
        'היום ב־02:00',
        // Carbon::parse('2018-01-04 23:00:00')->addHours(2)->calendar(Carbon::parse('2018-01-04 23:00:00'))
        'מחר ב־01:00',
        // Carbon::parse('2018-01-07 00:00:00')->addDays(2)->calendar(Carbon::parse('2018-01-07 00:00:00'))
        'שלישי בשעה 00:00',
        // Carbon::parse('2018-01-08 00:00:00')->subDay()->calendar(Carbon::parse('2018-01-08 00:00:00'))
        'אתמול ב־00:00',
        // Carbon::parse('2018-01-04 00:00:00')->subDays(1)->calendar(Carbon::parse('2018-01-04 00:00:00'))
        'אתמול ב־00:00',
        // Carbon::parse('2018-01-04 00:00:00')->subDays(2)->calendar(Carbon::parse('2018-01-04 00:00:00'))
        'ביום שלישי האחרון בשעה 00:00',
        // Carbon::parse('2018-01-04 00:00:00')->subDays(3)->calendar(Carbon::parse('2018-01-04 00:00:00'))
        'ביום שני האחרון בשעה 00:00',
        // Carbon::parse('2018-01-04 00:00:00')->subDays(4)->calendar(Carbon::parse('2018-01-04 00:00:00'))
        'ביום ראשון האחרון בשעה 00:00',
        // Carbon::parse('2018-01-04 00:00:00')->subDays(5)->calendar(Carbon::parse('2018-01-04 00:00:00'))
        'ביום שבת האחרון בשעה 00:00',
        // Carbon::parse('2018-01-04 00:00:00')->subDays(6)->calendar(Carbon::parse('2018-01-04 00:00:00'))
        'ביום שישי האחרון בשעה 00:00',
        // Carbon::parse('2018-01-03 00:00:00')->subDays(6)->calendar(Carbon::parse('2018-01-03 00:00:00'))
        'ביום חמישי האחרון בשעה 00:00',
        // Carbon::parse('2018-01-02 00:00:00')->subDays(6)->calendar(Carbon::parse('2018-01-02 00:00:00'))
        'ביום רביעי האחרון בשעה 00:00',
        // Carbon::parse('2018-01-07 00:00:00')->subDays(2)->calendar(Carbon::parse('2018-01-07 00:00:00'))
        'ביום שישי האחרון בשעה 00:00',
        // Carbon::parse('2018-01-01 00:00:00')->isoFormat('Qo Mo Do Wo wo')
        '1 1 1 1 1',
        // Carbon::parse('2018-01-02 00:00:00')->isoFormat('Do wo')
        '2 1',
        // Carbon::parse('2018-01-03 00:00:00')->isoFormat('Do wo')
        '3 1',
        // Carbon::parse('2018-01-04 00:00:00')->isoFormat('Do wo')
        '4 1',
        // Carbon::parse('2018-01-05 00:00:00')->isoFormat('Do wo')
        '5 1',
        // Carbon::parse('2018-01-06 00:00:00')->isoFormat('Do wo')
        '6 1',
        // Carbon::parse('2018-01-07 00:00:00')->isoFormat('Do wo')
        '7 2',
        // Carbon::parse('2018-01-11 00:00:00')->isoFormat('Do wo')
        '11 2',
        // Carbon::parse('2018-02-09 00:00:00')->isoFormat('DDDo')
        '40',
        // Carbon::parse('2018-02-10 00:00:00')->isoFormat('DDDo')
        '41',
        // Carbon::parse('2018-04-10 00:00:00')->isoFormat('DDDo')
        '100',
        // Carbon::parse('2018-02-10 00:00:00', 'Europe/Paris')->isoFormat('h:mm a z')
        '12:00 לפנות בוקר CET',
        // Carbon::parse('2018-02-10 00:00:00')->isoFormat('h:mm A, h:mm a')
        '12:00 לפנות בוקר, 12:00 לפנות בוקר',
        // Carbon::parse('2018-02-10 01:30:00')->isoFormat('h:mm A, h:mm a')
        '1:30 לפנות בוקר, 1:30 לפנות בוקר',
        // Carbon::parse('2018-02-10 02:00:00')->isoFormat('h:mm A, h:mm a')
        '2:00 לפנות בוקר, 2:00 לפנות בוקר',
        // Carbon::parse('2018-02-10 06:00:00')->isoFormat('h:mm A, h:mm a')
        '6:00 בבוקר, 6:00 בבוקר',
        // Carbon::parse('2018-02-10 10:00:00')->isoFormat('h:mm A, h:mm a')
        '10:00 לפני הצהריים, 10:00 לפנה"צ',
        // Carbon::parse('2018-02-10 12:00:00')->isoFormat('h:mm A, h:mm a')
        '12:00 אחרי הצהריים, 12:00 אחה"צ',
        // Carbon::parse('2018-02-10 17:00:00')->isoFormat('h:mm A, h:mm a')
        '5:00 אחרי הצהריים, 5:00 אחה"צ',
        // Carbon::parse('2018-02-10 21:30:00')->isoFormat('h:mm A, h:mm a')
        '9:30 בערב, 9:30 בערב',
        // Carbon::parse('2018-02-10 23:00:00')->isoFormat('h:mm A, h:mm a')
        '11:00 בערב, 11:00 בערב',
        // Carbon::parse('2018-01-01 00:00:00')->ordinal('hour')
        '0',
        // Carbon::now()->subSeconds(1)->diffForHumans()
        'לפני שנייה',
        // Carbon::now()->subSeconds(1)->diffForHumans(null, false, true)
        'לפני שניה',
        // Carbon::now()->subSeconds(2)->diffForHumans()
        'לפני 2 שניות',
        // Carbon::now()->subSeconds(2)->diffForHumans(null, false, true)
        'לפני 2 שניות',
        // Carbon::now()->subMinutes(1)->diffForHumans()
        'לפני דקה',
        // Carbon::now()->subMinutes(1)->diffForHumans(null, false, true)
        'לפני דקה',
        // Carbon::now()->subMinutes(2)->diffForHumans()
        'לפני שתי דקות',
        // Carbon::now()->subMinutes(2)->diffForHumans(null, false, true)
        'לפני שתי דקות',
        // Carbon::now()->subHours(1)->diffForHumans()
        'לפני שעה',
        // Carbon::now()->subHours(1)->diffForHumans(null, false, true)
        'לפני שעה',
        // Carbon::now()->subHours(2)->diffForHumans()
        'לפני שעתיים',
        // Carbon::now()->subHours(2)->diffForHumans(null, false, true)
        'לפני שעתיים',
        // Carbon::now()->subDays(1)->diffForHumans()
        'לפני יום',
        // Carbon::now()->subDays(1)->diffForHumans(null, false, true)
        'לפני יום',
        // Carbon::now()->subDays(2)->diffForHumans()
        'לפני יומיים',
        // Carbon::now()->subDays(2)->diffForHumans(null, false, true)
        'לפני יומיים',
        // Carbon::now()->subWeeks(1)->diffForHumans()
        'לפני שבוע',
        // Carbon::now()->subWeeks(1)->diffForHumans(null, false, true)
        'לפני שבוע',
        // Carbon::now()->subWeeks(2)->diffForHumans()
        'לפני שבועיים',
        // Carbon::now()->subWeeks(2)->diffForHumans(null, false, true)
        'לפני שבועיים',
        // Carbon::now()->subMonths(1)->diffForHumans()
        'לפני חודש',
        // Carbon::now()->subMonths(1)->diffForHumans(null, false, true)
        'לפני חודש',
        // Carbon::now()->subMonths(2)->diffForHumans()
        'לפני חודשיים',
        // Carbon::now()->subMonths(2)->diffForHumans(null, false, true)
        'לפני חודשיים',
        // Carbon::now()->subYears(1)->diffForHumans()
        'לפני שנה',
        // Carbon::now()->subYears(1)->diffForHumans(null, false, true)
        'לפני שנה',
        // Carbon::now()->subYears(2)->diffForHumans()
        'לפני שנתיים',
        // Carbon::now()->subYears(2)->diffForHumans(null, false, true)
        'לפני שנתיים',
        // Carbon::now()->addSecond()->diffForHumans()
        'בעוד שנייה מעכשיו',
        // Carbon::now()->addSecond()->diffForHumans(null, false, true)
        'בעוד שניה מעכשיו',
        // Carbon::now()->addSecond()->diffForHumans(Carbon::now())
        'אחרי שנייה',
        // Carbon::now()->addSecond()->diffForHumans(Carbon::now(), false, true)
        'אחרי שניה',
        // Carbon::now()->diffForHumans(Carbon::now()->addSecond())
        'לפני שנייה',
        // Carbon::now()->diffForHumans(Carbon::now()->addSecond(), false, true)
        'לפני שניה',
        // Carbon::now()->addSecond()->diffForHumans(Carbon::now(), true)
        'שנייה',
        // Carbon::now()->addSecond()->diffForHumans(Carbon::now(), true, true)
        'שניה',
        // Carbon::now()->diffForHumans(Carbon::now()->addSecond()->addSecond(), true)
        '2 שניות',
        // Carbon::now()->diffForHumans(Carbon::now()->addSecond()->addSecond(), true, true)
        '2 שניות',
        // Carbon::now()->addSecond()->diffForHumans(null, false, true, 1)
        'בעוד שניה מעכשיו',
        // Carbon::now()->addMinute()->addSecond()->diffForHumans(null, true, false, 2)
        'דקה שנייה',
        // Carbon::now()->addYears(2)->addMonths(3)->addDay()->addSecond()->diffForHumans(null, true, true, 4)
        'שנתיים 3 חודשים יום שניה',
        // Carbon::now()->addYears(3)->diffForHumans(null, null, false, 4)
        'בעוד 3 שנים מעכשיו',
        // Carbon::now()->subMonths(5)->diffForHumans(null, null, true, 4)
        'לפני 5 חודשים',
        // Carbon::now()->subYears(2)->subMonths(3)->subDay()->subSecond()->diffForHumans(null, null, true, 4)
        'לפני שנתיים 3 חודשים יום שניה',
        // Carbon::now()->addWeek()->addHours(10)->diffForHumans(null, true, false, 2)
        'שבוע 10 שעות',
        // Carbon::now()->addWeek()->addDays(6)->diffForHumans(null, true, false, 2)
        'שבוע 6 ימים',
        // Carbon::now()->addWeek()->addDays(6)->diffForHumans(null, true, false, 2)
        'שבוע 6 ימים',
        // Carbon::now()->addWeek()->addDays(6)->diffForHumans(["join" => true, "parts" => 2])
        'בעוד שבוע ו -6 ימים מעכשיו',
        // Carbon::now()->addWeeks(2)->addHour()->diffForHumans(null, true, false, 2)
        'שבועיים שעה',
        // Carbon::now()->addHour()->diffForHumans(["aUnit" => true])
        'בעוד שעה מעכשיו',
        // CarbonInterval::days(2)->forHumans()
        'יומיים',
        // CarbonInterval::create('P1DT3H')->forHumans(true)
        'יום 3 שעות',
    ];
}

==> php-nesbot-carbon_2.65.0.orig.tar.xz: php-nesbot-carbon-2.65.0/tests/Localization/HeIlTest.php <==
<?php

declare(strict_types=1);

/**
 * This file is part of the Carbon package.
 *
 * (c) Brian Nesbitt <brian@nesbot.com>
 *
 * For the full copyright and license information, please view the LICENSE
 * file that was distributed with this source code.
 */

namespace Tests\Localization;

/**
 * @group localization
 */
class HeIlTest extends LocalizationTestCase
{
    public const LOCALE = 'he_IL'; // Hebrew

    public const CASES = [
        // Carbon::parse('2018-01-04 00:00:00')->addDays(1)->calendar(Carbon::parse('2018-01-04 00:00:00'))
        // 'Tomorrow at 12:00 AM'
        'מחר ב־00:00',

        // Carbon::parse('2018-01-04 00:00:00')->addDays(2)->calendar(Carbon::parse('2018-01-04 00:00:00'))
        // 'Saturday at 12:00 AM'
        'שבת בשעה 00:00',

        // Carbon::parse('2018-01-04 00:00:00')->addDays(3)->calendar(Carbon::parse('2018-01-04 00:00:00'))
        // 'Sunday at 12:00 AM'
        'ראשון בשעה 00:00',

        // Carbon::parse('2018-01-04 00:00:00')->addDays(4)->calendar(Carbon::parse('2018-01-04 00:00:00'))
        // 'Monday at 12:00 AM'
        'שני בשעה 00:00',

        // Carbon::parse('2018-01-04 00:00:00')->addDays(5)->calendar(Carbon::parse('2018-01-04 00:00:00'))
        // 'Tuesday at 12:00 AM'
        'שלישי בשעה 00:00',

        // Carbon::parse('2018-01-04 00:00:00')->addDays(6)->calendar(Carbon::parse('2018-01-04 00:00:00'))
        // 'Wednesday at 12:00 AM'
        'רביעי בשעה 00:00',

        // Carbon::parse('2018-01-05 00:00:00')->addDays(6)->calendar(Carbon::parse('2018-01-05 00:00:00'))
        // 'Thursday at 12:00 AM'
        'חמישי בשעה 00:00',

        // Carbon::parse('2018-01-06 00:00:00')->addDays(6)->calendar(Carbon::parse('2018-01-06 00:00:00'))
        // 'Friday at 12:00 AM'
        'שישי בשעה 00:00',

        // Carbon::parse('2018-01-07 00:00:00')->addDays(2)->calendar(Carbon::parse('2018-01-07 00:00:00'))
        // 'Tuesday at 12:00 AM'
        'שלישי בשעה 00:00',

        // Carbon::parse('2018-01-07 00:00:00')->addDays(3)->calendar(Carbon::parse('2018-01-07 00:00:00'))
        // 'Wednesday at 12:00 AM'
        'רביעי בשעה 00:00',

        // Carbon::parse('2018-01-07 00:00:00')->addDays(4)->calendar(Carbon::parse('2018-01-07 00:00:00'))
        // 'Thursday at 12:00 AM'
        'חמישי בשעה 00:00',

        // Carbon::parse('2018-01-07 00:00:00')->addDays(5)->calendar(Carbon::parse('2018-01-07 00:00:00'))
        // 'Friday at 12:00 AM'
        'שישי בשעה 00:00',

        // Carbon::parse('2018-01-07 00:00:00')->addDays(6)->calendar(Carbon::parse('2018-01-07 00:00:00'))
        // 'Saturday at 12:00 AM'
        'שבת בשעה 00:00',

        // Carbon::now()->subDays(2)->calendar()
        // 'Last Sunday at 8:49 PM'
        'ביום ראשון האחרון בשעה 20:49',

        // Carbon::parse('2018-01-04 00:00:00')->subHours(2)->calendar(Carbon::parse('2018-01-04 00:00:00'))
        // 'Yesterday at 10:00 PM'
        'אתמול ב־22:00',

        // Carbon::parse('2018-01-04 12:00:00')->subHours(2)->calendar(Carbon::parse('2018-01-04 12:00:00'))
        // 'Today at 10:00 AM'
        'היום ב־10:00',

        // Carbon::parse('2018-01-04 00:00:00')->addHours(2)->calendar(Carbon::parse('2018-01-04 00:00:00'))
        // 'Today at 2:00 AM'
        'היום ב־02:00',

        // Carbon::parse('2018-01-04 23:00:00')->addHours(2)->calendar(Carbon::parse('2018-01-04 23:00:00'))
        // 'Tomorrow at 1:00 AM'
        'מחר ב־01:00',

        // Carbon::parse('2018-01-07 00:00:00')->addDays(2)->calendar(Carbon::parse('2018-01-07 00:00:00'))
        // 'Tuesday at 12:00 AM'
        'שלישי בשעה 00:00',

        // Carbon::parse('2018-01-08 00:00:00')->subDay()->calendar(Carbon::parse('2018-01-08 00:00:00'))
        // 'Yesterday at 12:00 AM'
        'אתמול ב־00:00',

        // Carbon::parse('2018-01-04 00:00:00')->subDays(1)->calendar(Carbon::parse('2018-01-04 00:00:00'))
        // 'Yesterday at 12:00 AM'
        'אתמול ב־00:00',

        // Carbon::parse('2018-01-04 00:00:00')->subDays(2)->calendar(Carbon::parse('2018-01-04 00:00:00'))
        // 'Last Tuesday at 12:00 AM'
        'ביום שלישי האחרון בשעה 00:00',

        // Carbon::parse('2018-01-04 00:00:00')->subDays(3)->calendar(Carbon::parse('2018-01-04 00:00:00'))
        // 'Last Monday at 12:00 AM'
        'ביום שני האחרון בשעה 00:00',

        // Carbon::parse('2018-01-04 00:00:00')->subDays(4)->calendar(Carbon::parse('2018-01-04 00:00:00'))
        // 'Last Sunday at 12:00 AM'
        'ביום ראשון האחרון בשעה 00:00',

        // Carbon::parse('2018-01-04 00:00:00')->subDays(5)->calendar(Carbon::parse('2018-01-04 00:00:00'))
        // 'Last Saturday at 12:00 AM'
        'ביום שבת האחרון בשעה 00:00',

        // Carbon::parse('2018-01-04 00:00:00')->subDays(6)->calendar(Carbon::parse('2018-01-04 00:00:00'))
        // 'Last Friday at 12:00 AM'
        'ביום שישי האחרון בשעה 00:00',

        // Carbon::parse('2018-01-03 00:00:00')->subDays(6)->calendar(Carbon::parse('2018-01-03 00:00:00'))
        // 'Last Thursday at 12:00 AM'
        'ביום חמישי האחרון בשעה 00:00',

        // Carbon::parse('2018-01-02 00:00:00')->subDays(6)->calendar(Carbon::parse('2018-01-02 00:00:00'))
        // 'Last Wednesday at 12:00 AM'
        'ביום רביעי האחרון בשעה 00:00',

        // Carbon::parse('2018-01-07 00:00:00')->subDays(2)->calendar(Carbon::parse('2018-01-07 00:00:00'))
        // 'Last Friday at 12:00 AM'
        'ביום שישי האחרון בשעה 00:00',

        // Carbon::parse('2018-01-01 00:00:00')->isoFormat('Qo Mo Do Wo wo')
        // '1st 1st 1st 1st 1st'
        '1 1 1 1 1',

        // Carbon::parse('2018-01-02 00:00:00')->isoFormat('Do wo')
        // '2nd 1st'
        '2 1',

        // Carbon::parse('2018-01-03 00:00:00')->isoFormat('Do wo')
        // '3rd 1st'
        '3 1',

        // Carbon::parse('2018-01-04 00:00:00')->isoFormat('Do wo')
        // '4th 1st'
        '4 1',

        // Carbon::parse('2018-01-05 00:00:00')->isoFormat('Do wo')
        // '5th 1st'
        '5 1',

        // Carbon::parse('2018-01-06 00:00:00')->isoFormat('Do wo')
        // '6th 1st'
        '6 1',

        // Carbon::parse('2018-01-07 00:00:00')->isoFormat('Do wo')
        // '7th 2nd'
        '7 2',

        // Carbon::parse('2018-01-11 00:00:00')->isoFormat('Do wo')
        // '11th 2nd'
        '11 2',

        // Carbon::parse('2018-02-09 00:00:00')->isoFormat('DDDo')
        // '40th'
        '40',

        // Carbon::parse('2018-02-10 00:00:00')->isoFormat('DDDo')
        // '41st'
        '41',

        // Carbon::parse('2018-04-10 00:00:00')->isoFormat('DDDo')
        // '100th'
        '100',

        // Carbon::parse('2018-02-10 00:00:00', 'Europe/Paris')->isoFormat('h:mm a z')
        // '12:00 am CET'
        '12:00 לפנות בוקר CET',

        // Carbon::parse('2018-02-10 00:00:00')->isoFormat('h:mm A, h:mm a')
        // '12:00 AM, 12:00 am'
        '12:00 לפנות בוקר, 12:00 לפנות בוקר',

        // Carbon::parse('2018-02-10 01:30:00')->isoFormat('h:mm A, h:mm a')
        // '1:30 AM, 1:30 am'
        '1:30 לפנות בוקר, 1:30 לפנות בוקר',

        // Carbon::parse('2018-02-10 02:00:00')->isoFormat('h:mm A, h:mm a')
        // '2:00 AM, 2:00 am'
        '2:00 לפנות בוקר, 2:00 לפנות בוקר',

        // Carbon::parse('2018-02-10 06:00:00')->isoFormat('h:mm A, h:mm a')
        // '6:00 AM, 6:00 am'
        '6:00 בבוקר, 6:00 בבוקר',

        // Carbon::parse('2018-02-10 10:00:00')->isoFormat('h:mm A, h:mm a')
        // '10:00 AM, 10:00 am'
        '10:00 לפני הצהריים, 10:00 לפנה"צ',

        // Carbon::parse('2018-02-10 12:00:00')->isoFormat('h:mm A, h:mm a')
        // '12:00 PM, 12:00 pm'
        '12:00 אחרי הצהריים, 12:00 אחה"צ',

        // Carbon::parse('2018-02-10 17:00:00')->isoFormat('h:mm A, h:mm a')
        // '5:00 PM, 5:00 pm'
        '5:00 אחרי הצהריים, 5:00 אחה"צ',

        // Carbon::parse('2018-02-10 21:30:00')->isoFormat('h:mm A, h:mm a')
        // '9:30 PM, 9:30 pm'
        '9:30 בערב, 9:30 בערב',

        // Carbon::parse('2018-02-10 23:00:00')->isoFormat('h:mm A, h:mm a')
        // '11:00 PM, 11:00 pm'
        '11:00 בערב, 11:00 בערב',

        // Carbon::parse('2018-01-01 00:00:00')->ordinal('hour')
        // '0th'
        '0',

        // Carbon::now()->subSeconds(1)->diffForHumans()
        // '1 second ago'
        'לפני שנייה',

        // Carbon::now()->subSeconds(1)->diffForHumans(null, false, true)
        // '1s ago'
        'לפני שניה',

        // Carbon::now()->subSeconds(2)->diffForHumans()
        // '2 seconds ago'
        'לפני 2 שניות',

        // Carbon::now()->subSeconds(2)->diffForHumans(null, false, true)
        // '2s ago'
        'לפני 2 שנ׳',

        // Carbon::now()->subMinutes(1)->diffForHumans()
        // '1 minute ago'
        'לפני דקה',

        // Carbon::now()->subMinutes(1)->diffForHumans(null, false, true)
        // '1m ago'
        'לפני דקה',

        // Carbon::now()->subMinutes(2)->diffForHumans()
        // '2 minutes ago'
        'לפני שתי דקות',

        // Carbon::now()->subMinutes(2)->diffForHumans(null, false, true)
        // '2m ago'
        'לפני 2 דק׳',

        // Carbon::now()->subHours(1)->diffForHumans()
        // '1 hour ago'
        'לפני שעה',

        // Carbon::now()->subHours(1)->diffForHumans(null, false, true)
        // '1h ago'
        'לפני שעה',

        // Carbon::now()->subHours(2)->diffForHumans()
        // '2 hours ago'
        'לפני שעתיים',

        // Carbon::now()->subHours(2)->diffForHumans(null, false, true)
        // '2h ago'
        'לפני 2 שע׳',

        // Carbon::now()->subDays(1)->diffForHumans()
        // '1 day ago'
        'לפני יום',

        // Carbon::now()->subDays(1)->diffForHumans(null, false, true)
        // '1d ago'
        'לפני יום',

        // Carbon::now()->subDays(2)->diffForHumans()
        // '2 days ago'
        'לפני יומיים',

        // Carbon::now()->subDays(2)->diffForHumans(null, false, true)
        // '2d ago'
        'לפני 2 ימ׳',

        // Carbon::now()->subWeeks(1)->diffForHumans()
        // '1 week ago'
        'לפני שבוע',

        // Carbon::now()->subWeeks(1)->diffForHumans(null, false, true)
        // '1w ago'
        'לפני שבוע',

        // Carbon::now()->subWeeks(2)->diffForHumans()
        // '2 weeks ago'
        'לפני שבועיים',

        // Carbon::now()->subWeeks(2)->diffForHumans(null, false, true)
        // '2w ago'
        'לפני 2 שב׳',

        // Carbon::now()->subMonths(1)->diffForHumans()
        // '1 month ago'
        'לפני חודש',

        // Carbon::now()->subMonths(1)->diffForHumans(null, false, true)
        // '1mo ago'
        'לפני חודש',

        // Carbon::now()->subMonths(2)->diffForHumans()
        // '2 months ago'
        'לפני חודשיים',

        // Carbon::now()->subMonths(2)->diffForHumans(null, false, true)
        // '2mos ago'
        'לפני 2 חו׳',

        // Carbon::now()->subYears(1)->diffForHumans()
        // '1 year ago'
        'לפני שנה',

        // Carbon::now()->subYears(1)->diffForHumans(null, false, true)
        // '1yr ago'
        'לפני שנה',

        // Carbon::now()->subYears(2)->diffForHumans()
        // '2 years ago'
        'לפני שנתיים',

        // Carbon::now()->subYears(2)->diffForHumans(null, false, true)
        // '2yrs ago'
        'לפני 2 שנ׳',

        // Carbon::now()->addSecond()->diffForHumans()
        // '1 second from now'
        'בעוד שנייה מעכשיו',

        // Carbon::now()->addSecond()->diffForHumans(null, false, true)
        // '1s from now'
        'בעוד שניה מעכשיו',

        // Carbon::now()->addSecond()->diffForHumans(Carbon::now())
        // '1 second after'
        'אחרי שנייה',

        // Carbon::now()->addSecond()->diffForHumans(Carbon::now(), false, true)
        // '1s after'
        'אחרי שניה',

        // Carbon::now()->diffForHumans(Carbon::now()->addSecond())
        // '1 second before'
        'לפני שנייה',

        // Carbon::now()->diffForHumans(Carbon::now()->addSecond(), false, true)
        // '1s before'
        'לפני שניה',

        // Carbon::now()->addSecond()->diffForHumans(Carbon::now(), true)
        // '1 second'
        'שנייה',

        // Carbon::now()->addSecond()->diffForHumans(Carbon::now(), true, true)
        // '1s'
        'שניה',

        // Carbon::now()->diffForHumans(Carbon::now()->addSecond()->addSecond(), true)
        // '2 seconds'
        '2 שניות',

        // Carbon::now()->diffForHumans(Carbon::now()->addSecond()->addSecond(), true, true)
        // '2s'
        '2 שנ׳',

        // Carbon::now()->addSecond()->diffForHumans(null, false, true, 1)
        // '1s from now'
        'בעוד שניה מעכשיו',

        // Carbon::now()->addMinute()->addSecond()->diffForHumans(null, true, false, 2)
        // '1 minute 1 second'
        'דקה שנייה',

        // Carbon::now()->addYears(2)->addMonths(3)->addDay()->addSecond()->diffForHumans(null, true, true, 4)
        // '2yrs 3mos 1d 1s'
        '2 שנ׳ 3 חו׳ יום שניה',

        // Carbon::now()->addYears(3)->diffForHumans(null, null, false, 4)
        // '3 years from now'
        'בעוד 3 שנים מעכשיו',

        // Carbon::now()->subMonths(5)->diffForHumans(null, null, true, 4)
        // '5mos ago'
        'לפני 5 חו׳',

        // Carbon::now()->subYears(2)->subMonths(3)->subDay()->subSecond()->diffForHumans(null, null, true, 4)
        // '2yrs 3mos 1d 1s ago'
        'לפני 2 שנ׳ 3 חו׳ יום שניה',

        // Carbon::now()->addWeek()->addHours(10)->diffForHumans(null, true, false, 2)
        // '1 week 10 hours'
        'שבוע 10 שעות',

        // Carbon::now()->addWeek()->addDays(6)->diffForHumans(null, true, false, 2)
        // '1 week 6 days'
        'שבוע 6 ימים',

        // Carbon::now()->addWeek()->addDays(6)->diffForHumans(null, true, false, 2)
        // '1 week 6 days'
        'שבוע 6 ימים',

        // Carbon::now()->addWeek()->addDays(6)->diffForHumans(["join" => true, "parts" => 2])
        // '1 week and 6 days from now'
        'בעוד שבוע ו -6 ימים מעכשיו',

        // Carbon::now()->addWeeks(2)->addHour()->diffForHumans(null, true, false, 2)
        // '2 weeks 1 hour'
        'שבועיים שעה',

        // Carbon::now()->addHour()->diffForHumans(["aUnit" => true])
        // 'an hour from now'
        'בעוד שעה מעכשיו',

        // CarbonInterval::days(2)->forHumans()
        // '2 days'
        'יומיים',

        // CarbonInterval::create('P1DT3H')->forHumans(true)
        // '1d 3h'
        'יום 3 שע׳',
    ];
}
